@@ -28,7 +28,7 @@ class IndexMonitor:
                 self.receivers = email_list
 
             yag = yagmail.SMTP('858776278@qq.com', 'uurpxchfekfebahj', host='smtp.qq.com', port='465')
-            yag.send(self.receivers, '指数跟踪', '跟踪指标和买卖建议见附件', ['./指数统计指标.xlsx'])
+            yag.send(self.receivers, '指数', '买卖建议见附件', ['./指数统计指标.xlsx'])
         except Exception as e:
             email_list = SendEmail.get_email_list()
             if email_list is not None and len(email_list) > 0:
@@ -92,7 +92,8 @@ class IndexMonitor:
         etf_name = []
         pe_less_prob_10y = []
         pe_less_prob_10y_2m_ago = []
-        pe_diff_2m_ago_signal = []
+        # pe_diff_2m_ago_signal = []
+        pe_percent_signal = []
         pe_mean_div_rt = []
         pe_max_rt = []
         pe_latest = []
@@ -111,8 +112,8 @@ class IndexMonitor:
             etf_name.append(stat.etf_name)
             pe_less_prob_10y.append(int(round(stat.pe_less_prob_10y)))
             pe_less_prob_10y_2m_ago.append(int(round(stat.pe_less_prob_10y_2m_ago)))
-            pe_diff_2m_ago_signal.append(
-                self.pe_cur_ago_signal(stat.pe_latest, stat.pe_2m_ago))
+            # pe_diff_2m_ago_signal.append(self.pe_cur_ago_signal(stat.pe_latest, stat.pe_2m_ago))
+            pe_percent_signal.append(self.pe_percent_signal(stat.pe_less_prob_10y))
             pe_mean_div_rt.append(round(stat.pe_latest / stat.pe_mean_10y, 2))
             pe_max_rt.append(round(stat.pe_latest / stat.pe_max, 2))
             pe_latest.append(stat.pe_latest)
@@ -127,11 +128,11 @@ class IndexMonitor:
         df = pandas.DataFrame(
             data=np.array(
                 [index_code, index_name, etf_code, etf_name, pe_less_prob_10y, pe_mean_div_rt,
-                 pe_diff_2m_ago_signal,
+                 pe_percent_signal,
                  pe_less_prob_10y_2m_ago, pe_max_rt, pe_latest, pe_mean, pe_max, pb_less_prob_10y,
                  ai_signal,
                  pe_volatility_3y, real_year, last_dt]).T,
-            columns=['指数代码', '指数名称', 'ETF代码', 'ETF名称', 'PE分位', 'PE均值比', 'PE2m信号',
+            columns=['指数代码', '指数名称', 'ETF代码', 'ETF名称', 'PE分位', 'PE均值比', '估值水平',
                      'PE分位2m', 'PE:max_rt', 'PE', 'PE均值', 'PE最大值', 'PB分位', 'AI', '3年波动', '跟踪年数',
                      '最后日期'])
         return df
@@ -148,11 +149,23 @@ class IndexMonitor:
     @staticmethod
     def pe_cur_ago_signal(cur_pe, pe_ago):
         if cur_pe < pe_ago:
-            return '-:' + str(int(round(abs((cur_pe - pe_ago) * 100 / pe_ago))))
+            return '-:' + str(int(round(abs((cur_pe - pe_ago) * 100 / pe_ago)))) + '%'
         elif cur_pe > pe_ago:
-            return '+:' + str(int(round(abs((cur_pe - pe_ago) * 100 / pe_ago))))
+            return '+:' + str(int(round(abs((cur_pe - pe_ago) * 100 / pe_ago)))) + "%"
         else:
-            return ''
+            return '0'
+        # '↓ ↑'
+
+    @staticmethod
+    def pe_percent_signal(pe_percent):
+        if pe_percent < 35:
+            return '低估'
+        elif 35 <= pe_percent <= 65:
+            return '合理'
+        elif 65 < pe_percent < 75:
+            return '偏高'
+        else:
+            return '高估'
         # '↓ ↑'
 
 
